pub struct PaginatedOptions {
pub cursor: Option<String>,
pub limit: Option<u16>,
}Expand description
Cursor is a unique identifier for a page of results by which the next page can be fetched.
Limit is the maximum number of results to return per page.
Fields
cursor: Option<String>limit: Option<u16>Auto Trait Implementations
impl Freeze for PaginatedOptions
impl RefUnwindSafe for PaginatedOptions
impl Send for PaginatedOptions
impl Sync for PaginatedOptions
impl Unpin for PaginatedOptions
impl UnsafeUnpin for PaginatedOptions
impl UnwindSafe for PaginatedOptions