pub struct LightValidatorConfig {
pub enable_indexer: bool,
pub enable_prover: bool,
pub wait_time: u64,
pub sbf_programs: Vec<(String, String)>,
pub upgradeable_programs: Vec<UpgradeableProgramConfig>,
pub limit_ledger_size: Option<u64>,
pub use_surfpool: bool,
pub validator_args: Vec<String>,
}Fields
enable_indexer: boolenable_prover: boolwait_time: u64sbf_programs: Vec<(String, String)>Non-upgradeable programs: (program_id, program_path)
upgradeable_programs: Vec<UpgradeableProgramConfig>Upgradeable programs to deploy with a valid upgrade authority. Use this when the program needs a valid upgrade authority (e.g., for compression config).
limit_ledger_size: Option<u64>use_surfpool: boolUse surfpool instead of solana-test-validator
validator_args: Vec<String>Additional arguments to pass to the validator (e.g., “–account