pub struct LightClient {
pub client: RpcClient,
pub payer: Keypair,
pub retry_config: RetryConfig,
pub indexer: Option<PhotonIndexer>,
pub state_merkle_trees: Vec<TreeInfo>,
}Fields
client: RpcClientpayer: Keypairretry_config: RetryConfigindexer: Option<PhotonIndexer>state_merkle_trees: Vec<TreeInfo>Implementations
Sourceimpl LightClient
impl LightClient
pub async fn new_with_retry( config: LightClientConfig, retry_config: Option<RetryConfig>, ) -> Result<Self, RpcError>
pub fn add_indexer(&mut self, url: String)
Sourceimpl LightClient
impl LightClient
Sourcepub async fn warp_to_slot(&self, slot: Slot) -> Result<Value, RpcError>
pub async fn warp_to_slot(&self, slot: Slot) -> Result<Value, RpcError>
Instantly advances the validator to the given slot using surfpool’s
surfnet_timeTravel RPC method. This is much faster than polling
get_slot in a loop and is intended for testing against surfpool.
Returns the EpochInfo after the time travel, or an error if the
RPC call fails (e.g. when not running against surfpool).