#[repr(C)]pub struct AccessMetadata {
pub owner: ZeroCopyPubkey,
pub program_owner: ZeroCopyPubkey,
pub forester: ZeroCopyPubkey,
}Fields
owner: ZeroCopyPubkeyOwner of the Merkle tree.
program_owner: ZeroCopyPubkeyProgram owner of the Merkle tree. This will be used for program owned Merkle trees.
forester: ZeroCopyPubkeyOptional privileged forester pubkey, can be set for custom Merkle trees without a network fee. Merkle trees without network fees are not forested by light foresters. The variable is not used in the account compression program but the registry program. The registry program implements access control to prevent contention during forester. The forester pubkey specified in this struct can bypass contention checks.
Implementations
Sourceimpl AccessMetadata
impl AccessMetadata
pub fn new( owner: ZeroCopyPubkey, program_owner: Option<ZeroCopyPubkey>, forester: Option<ZeroCopyPubkey>, ) -> AccessMetadata